@@ -94,6 +94,7 @@ void qjackctlMainForm::init (void)
     m_pJackClient   = NULL;
     m_bJackDetach   = false;
     m_bJackSurvive  = false;
+    m_bJackShutdown = false;
     m_pAlsaSeq      = NULL;
     m_iStartDelay   = 0;
     m_iTimerDelay   = 0;
@@ -453,14 +454,13 @@ void qjackctlMainForm::shellExecute ( const QString& sShellCommand, const QStrin
 
     appendMessages(sStartMessage);
     appendMessagesColor(sTemp.stripWhiteSpace(), "#990099");
-    QApplication::eventLoop()->processEvents(QEventLoop::ExcludeUserInput);
+	stabilize(QJACKCTL_TIMER_MSECS);
+
     // Execute and set exit status message...
     sTemp = sStopMessage + formatExitStatus(::system(sTemp));
-   // Wait a litle bit before continue...
-    QTime t;
-    t.start();
-    while (t.elapsed() < QJACKCTL_TIMER_MSECS)
-        QApplication::eventLoop()->processEvents(QEventLoop::ExcludeUserInput);
+
+	// Wait a litle bit before continue...
+	stabilize(QJACKCTL_TIMER_MSECS);
     // Final log message...
     appendMessages(sTemp);
 }
@@ -509,6 +509,7 @@ void qjackctlMainForm::startJack (void)
 
     // Now we're sure it ain't detached.
     updateServerState(QJACKCTL_STARTING);
+	m_bJackShutdown = false;
 	m_bJackDetach = false;
 
     // Load primary/default server preset...
@@ -629,6 +630,10 @@ void qjackctlMainForm::startJack (void)
 			m_pJack->addArgument("-i" + QString::number(m_preset.iInChannels));
 		if (m_preset.iOutChannels > 0 && m_preset.iAudio != QJACKCTL_CAPTURE)
 			m_pJack->addArgument("-o" + QString::number(m_preset.iOutChannels));
+#ifdef CONFIG_JACK_MIDI
+		if (!m_preset.sMidiDriver.isEmpty())
+			m_pJack->addArgument("-X" + m_preset.sMidiDriver);
+#endif
     }
     else if (bOss) {
         if (m_preset.bIgnoreHW)
@@ -736,8 +741,11 @@ void qjackctlMainForm::stopJack (void)
 {
 	// Check if we're allowed to stop (shutdown)...
 	if (m_pSetup->bQueryShutdown
-		&& m_pJack && m_pJack->isRunning() && !m_bJackSurvive
-		&& m_pConnectionsForm && m_pConnectionsForm->isJackConnected()
+		&& m_pJack && m_pJack->isRunning()
+		&& !m_bJackSurvive
+		&& m_pConnectionsForm 
+		&& (m_pConnectionsForm->isAudioConnected() ||
+			m_pConnectionsForm->isMidiConnected())
 		&& QMessageBox::warning(this,
 			tr("Warning") + " - " QJACKCTL_SUBTITLE1,
 			tr("Some client audio applications") + "\n" +
@@ -764,7 +772,7 @@ void qjackctlMainForm::stopJackServer (void)
     stopJackClient();
 
     // And try to stop server.
-    if (m_pJack && m_pJack->isRunning() && !m_bJackSurvive) {
+    if (m_pJack && (m_bJackShutdown || m_pJack->isRunning()) && !m_bJackSurvive) {
         appendMessages(tr("JACK is stopping..."));
         updateServerState(QJACKCTL_STOPPING);
 		// Do we have any pre-shutdown script?...
@@ -775,14 +783,14 @@ void qjackctlMainForm::stopJackServer (void)
 				tr("Shutdown script terminated"));
 		}
         // Now it's the time to real try stopping the server daemon...
-        m_pJack->tryTerminate();
-        // Give it some time to terminate gracefully and stabilize...
-        QTime t;
-        t.start();
-        while (t.elapsed() < QJACKCTL_TIMER_MSECS)
-            QApplication::eventLoop()->processEvents(QEventLoop::ExcludeUserInput);
-        // Keep on, if not exiting for good.
-		return;
+		if (!m_bJackShutdown) {
+			// Let's try...
+			m_pJack->tryTerminate();
+			// Give it some time to terminate gracefully and stabilize...
+			stabilize(QJACKCTL_TIMER_MSECS);
+			// Keep on, if not exiting for good.
+			return;
+		}
      }
 
 	// If we have a post-shutdown script enabled it must be called,
@@ -845,7 +853,7 @@ void qjackctlMainForm::processJackExit (void)
 
     if (m_pJack) {
         // Force final server shutdown...
-        if (!m_bJackSurvive) {
+        if (!m_bJackShutdown && !m_bJackSurvive) {
             appendMessages(tr("JACK was stopped") + formatExitStatus(m_pJack->exitStatus()));
             if (!m_pJack->normalExit())
                 m_pJack->kill();
@@ -1021,9 +1029,11 @@ void qjackctlMainForm::updateBezierLines (void)
         return;
 
     if (m_pConnectionsForm) {
-        m_pConnectionsForm->JackConnectView->setBezierLines(m_pSetup->bBezierLines);
+        m_pConnectionsForm->AudioConnectView->setBezierLines(m_pSetup->bBezierLines);
+        m_pConnectionsForm->MidiConnectView->setBezierLines(m_pSetup->bBezierLines);
         m_pConnectionsForm->AlsaConnectView->setBezierLines(m_pSetup->bBezierLines);
-        m_pConnectionsForm->JackConnectView->ConnectorView()->update();
+        m_pConnectionsForm->AudioConnectView->ConnectorView()->update();
+        m_pConnectionsForm->MidiConnectView->ConnectorView()->update();
         m_pConnectionsForm->AlsaConnectView->ConnectorView()->update();
     }
 
@@ -1271,6 +1281,16 @@ void qjackctlMainForm::stabilizeForm (void)
 }
 
 
+// Stabilize current business over the application event loop.
+void qjackctlMainForm::stabilize ( int msecs )
+{
+	QTime t;
+	t.start();
+	while (t.elapsed() < msecs)
+		QApplication::eventLoop()->processEvents(QEventLoop::ExcludeUserInput);
+}
+
+
 // Reset XRUN cache items.
 void qjackctlMainForm::resetXrunStats (void)
 {
@@ -1495,7 +1515,7 @@ void qjackctlMainForm::portNotifyEvent (void)
 {
     // Log some message here, if new.
     if (m_iJackRefresh == 0)
-        appendMessagesColor(tr("Audio connection graph change."), "#cc9966");
+        appendMessagesColor(tr("JACK connection graph change."), "#cc9966");
     // Do what has to be done.
     refreshJackConnections();
     // We'll be dirty too...
@@ -1540,6 +1560,9 @@ void qjackctlMainForm::shutNotifyEvent (void)
 {
     // Log this event.
     appendMessagesColor(tr("Shutdown notification."), "#cc6666");
+	// SHUTDOWN: JACK client handle is not valid anymore...
+	m_bJackShutdown = true;
+	m_pJackClient = NULL;
     // Do what has to be done.
     stopJackServer();
     // We're not detached anymore, anyway.
@@ -1557,7 +1580,7 @@ void qjackctlMainForm::alsaNotifySlot ( int /*fd*/ )
 #endif
     // Log some message here, if new.
     if (m_iAlsaRefresh == 0)
-        appendMessagesColor(tr("MIDI connection graph change."), "#66cc99");
+        appendMessagesColor(tr("ALSA connection graph change."), "#66cc99");
     // Do what has to be done.
     refreshAlsaConnections();
     // We'll be dirty too...
@@ -1612,7 +1635,8 @@ void qjackctlMainForm::timerSlot (void)
         // Are we about to refresh it, really?
         if (m_iJackRefresh > 0) {
             m_iJackRefresh = 0;
-            m_pConnectionsForm->refreshJack(true);
+            m_pConnectionsForm->refreshAudio(true);
+            m_pConnectionsForm->refreshMidi(true);
         }
         if (m_iAlsaRefresh > 0) {
             m_iAlsaRefresh = 0;
@@ -1639,7 +1663,7 @@ void qjackctlMainForm::jackConnectChanged (void)
 {
     // Just shake the audio connections status quo.
     if (++m_iJackDirty == 1)
-        appendMessagesColor(tr("Audio connection change."), "#9999cc");
+        appendMessagesColor(tr("JACK connection change."), "#9999cc");
 }
 
 
@@ -1648,7 +1672,7 @@ void qjackctlMainForm::alsaConnectChanged (void)
 {
     // Just shake the MIDI connections status quo.
     if (++m_iAlsaDirty == 1)
-        appendMessagesColor(tr("MIDI connection change."), "#cccc99");
+        appendMessagesColor(tr("ALSA connection change."), "#cccc99");
 }
 
 
@@ -1817,26 +1841,24 @@ bool qjackctlMainForm::startJackClient ( bool bDetach )
 // Stop jack audio client...
 void qjackctlMainForm::stopJackClient (void)
 {
-    // Deactivate us as a client...
-    if (m_pJackClient) {
-        jack_deactivate(m_pJackClient);
-        // Log deactivation here.
-        appendMessages(tr("Client deactivated."));
-    }
-    // Destroy our connections patchbay...
+    // Clear out the connections and patchbays...
     if (m_pConnectionsForm)
         m_pConnectionsForm->setJackClient(NULL);
     if (m_pPatchbayForm)
         m_pPatchbayForm->setJackClient(NULL);
 
+    // Deactivate and close us as a client...
+    if (m_pJackClient) {
+        jack_deactivate(m_pJackClient);
+        jack_client_close(m_pJackClient);
+		m_pJackClient = NULL;
+        // Log deactivation here.
+        appendMessages(tr("Client deactivated."));
+    }
+
     // Reset command-line configuration info.
     m_sJackCmdLine = QString::null;
 
-    // Close us as a client...
-    if (m_pJackClient)
-        jack_client_close(m_pJackClient);
-    m_pJackClient = NULL;
-
     // Displays are dimmed again.
     ServerModeTextLabel->setPaletteForegroundColor(Qt::darkYellow);
     DspLoadTextLabel->setPaletteForegroundColor(Qt::darkYellow);
@@ -1861,8 +1883,10 @@ void qjackctlMainForm::refreshConnections (void)
 void qjackctlMainForm::refreshJackConnections (void)
 {
     // Hack this as for a while.
-    if (m_pConnectionsForm && m_iJackRefresh == 0)
-        m_pConnectionsForm->stabilizeJack(false);
+    if (m_pConnectionsForm && m_iJackRefresh == 0) {
+        m_pConnectionsForm->stabilizeAudio(false);
+        m_pConnectionsForm->stabilizeMidi(false);
+	}
 
     // Just increment our intentions; it will be deferred
     // to be executed just on timer slot processing...
