@@ -1,7 +1,7 @@
 // qjackctlSetup.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2006, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -74,12 +74,7 @@ qjackctlSetup::qjackctlSetup (void)
     iConnectionsIconSize     = m_settings.readNumEntry("/ConnectionsIconSize", QJACKCTL_ICON_16X16);
     sConnectionsFont         = m_settings.readEntry("/ConnectionsFont", QString::null);
     bQueryClose              = m_settings.readBoolEntry("/QueryClose", true);
-    // hack: default keep on top to false for Macs, because window focus looks bad
-#ifdef __APPLE__
     bKeepOnTop               = m_settings.readBoolEntry("/KeepOnTop", false);
-#else
-    bKeepOnTop               = m_settings.readBoolEntry("/KeepOnTop", true);
-#endif
     bSystemTray              = m_settings.readBoolEntry("/SystemTray", false);
     bDelayedSetup            = m_settings.readBoolEntry("/DelayedSetup", false);
     bServerConfig            = m_settings.readBoolEntry("/ServerConfig", true);
@@ -213,14 +208,18 @@ bool qjackctlSetup::loadAliases ( const QString& sPreset )
 	// Load preset aliases...
 	const QString sAliasesKey = "/Aliases" + sSuffix;
     m_settings.beginGroup(sAliasesKey);
-	  m_settings.beginGroup("/Jack");
-	 	aliasJackOutputs.loadSettings(m_settings, "/Outputs");
-	 	aliasJackInputs.loadSettings(m_settings, "/Inputs");
-	  m_settings.endGroup();
-	  m_settings.beginGroup("/Alsa");
-	 	aliasAlsaOutputs.loadSettings(m_settings, "/Outputs");
-	 	aliasAlsaInputs.loadSettings(m_settings, "/Inputs");
-	  m_settings.endGroup();
+	m_settings.beginGroup("/Jack");	// FIXME: Audio
+	aliasAudioOutputs.loadSettings(m_settings, "/Outputs");
+	aliasAudioInputs.loadSettings(m_settings, "/Inputs");
+	m_settings.endGroup();
+	m_settings.beginGroup("/Midi");
+	aliasMidiOutputs.loadSettings(m_settings, "/Outputs");
+	aliasMidiInputs.loadSettings(m_settings, "/Inputs");
+	m_settings.endGroup();
+	m_settings.beginGroup("/Alsa");
+	aliasAlsaOutputs.loadSettings(m_settings, "/Outputs");
+	aliasAlsaInputs.loadSettings(m_settings, "/Inputs");
+	m_settings.endGroup();
     m_settings.endGroup();
 
     return true;
@@ -240,14 +239,18 @@ bool qjackctlSetup::saveAliases ( const QString& sPreset )
 	const QString sAliasesKey = "/Aliases" + sSuffix;
 	deleteKey(sAliasesKey);
     m_settings.beginGroup(sAliasesKey);
-	  m_settings.beginGroup("/Jack");
-	 	aliasJackOutputs.saveSettings(m_settings, "/Outputs");
-	 	aliasJackInputs.saveSettings(m_settings, "/Inputs");
-	  m_settings.endGroup();
-	  m_settings.beginGroup("/Alsa");
-	 	aliasAlsaOutputs.saveSettings(m_settings, "/Outputs");
-	 	aliasAlsaInputs.saveSettings(m_settings, "/Inputs");
-	  m_settings.endGroup();
+	m_settings.beginGroup("/Jack");	// FIXME: Audio
+	aliasAudioOutputs.saveSettings(m_settings, "/Outputs");
+	aliasAudioInputs.saveSettings(m_settings, "/Inputs");
+	m_settings.endGroup();
+	m_settings.beginGroup("/Midi");
+	aliasMidiOutputs.saveSettings(m_settings, "/Outputs");
+	aliasMidiInputs.saveSettings(m_settings, "/Inputs");
+	m_settings.endGroup();
+	m_settings.beginGroup("/Alsa");
+	aliasAlsaOutputs.saveSettings(m_settings, "/Outputs");
+	aliasAlsaInputs.saveSettings(m_settings, "/Inputs");
+	m_settings.endGroup();
     m_settings.endGroup();
 
     return true;
@@ -299,6 +302,7 @@ bool qjackctlSetup::loadPreset ( qjackctlPreset& preset, const QString& sPreset
     preset.iStartDelay  = m_settings.readNumEntry("/StartDelay", 2);
     preset.bVerbose     = m_settings.readBoolEntry("/Verbose", false);
     preset.iPortMax     = m_settings.readNumEntry("/PortMax", 256);
+    preset.sMidiDriver  = m_settings.readEntry("/MidiDriver", QString::null);
     m_settings.endGroup();
 
     return true;
@@ -346,6 +350,7 @@ bool qjackctlSetup::savePreset ( qjackctlPreset& preset, const QString& sPreset
     m_settings.writeEntry("/StartDelay",  preset.iStartDelay);
     m_settings.writeEntry("/Verbose",     preset.bVerbose);
     m_settings.writeEntry("/PortMax",     preset.iPortMax);
+    m_settings.writeEntry("/MidiDriver",  preset.sMidiDriver);
     m_settings.endGroup();
 
     return true;
