@@ -1,7 +1,7 @@
 // qjackctlSetup.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2006, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -73,6 +73,7 @@ struct qjackctlPreset
     int     iStartDelay;
     bool    bVerbose;
     int     iPortMax;
+	QString sMidiDriver;
 };
 
 // Common settings profile class.
@@ -152,8 +153,10 @@ public:
     QStringList patchbays;
 
 	// Aliases containers.
-	qjackctlConnectAlias aliasJackOutputs;
-	qjackctlConnectAlias aliasJackInputs;
+	qjackctlConnectAlias aliasAudioOutputs;
+	qjackctlConnectAlias aliasAudioInputs;
+	qjackctlConnectAlias aliasMidiOutputs;
+	qjackctlConnectAlias aliasMidiInputs;
 	qjackctlConnectAlias aliasAlsaOutputs;
 	qjackctlConnectAlias aliasAlsaInputs;
 
